@@ -16,7 +16,7 @@ test_that("sequence encoding is done correctly", {
     step_sequence_onehot(text, string_length = seq_length)
   
   obj <- rec %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   juiced_data <- juice(obj)  
   
@@ -35,7 +35,7 @@ test_that("custom extraction functions work works", {
     step_sequence_onehot(text, integer_key = "I", string_length = 10)
   
   obj <- rec %>%
-    prep(training = test_data, retain = TRUE)
+    prep()
   
   expect_equal(dim(juice(obj)), c(nrow(test_data), 10))
   
@@ -46,5 +46,5 @@ test_that("printing", {
   rec <- rec %>%
     step_sequence_onehot(text)
   expect_output(print(rec))
-  expect_output(prep(rec, training = test_data, verbose = TRUE))
+  expect_output(prep(rec, verbose = TRUE))
 })
